.. _welcome:

PHOXENE's Sxip drivers documentation
======================================

This module is a Python driver for PHOXENE's SxIP flash devices

This module is intended to be use by software developpers in order to speed-up the integration
of PHOXENE's flash devices by our customers.

Project page on GitHub: 
https://github.com/Phoxene/sxip-drivers

Download page: 
https://pypi.org/project/sxip-drivers/


Contents:

.. toctree::
   :maxdepth: 2

   presentation
   shortintro
   autodoc
   examples
